@@ -14,7 +14,8 @@ import click
 from .constants import OUTPUT, METHODS, EMOJI
 from .diffuse import diffuse as run_diffusion
 from .kernels import regularised_laplacian_kernel
-from .utils import process_network_from_cli, _process_input
+from .process_input import process_input
+from .utils import process_network_from_cli
 
 logger = logging.getLogger(__name__)
 
@@ -58,7 +59,7 @@ def kernel(
 
     graph = process_network_from_cli(network)
 
-    click.secho(f'{EMOJI} Calculating regulatised Laplacian kernel. This might take a while... {EMOJI}')
+    click.secho(f'{EMOJI} Calculating regularized Laplacian kernel. This might take a while... {EMOJI}')
     exe_t_0 = time.time()
     background_mat = regularised_laplacian_kernel(graph)
     exe_t_f = time.time()
@@ -82,7 +83,7 @@ def kernel(
     type=click.Path(exists=True, dir_okay=False)
 )
 @click.option(
-    '-i', '--input',
+    '-i', '--data',
     help='Input data',
     required=True,
     type=click.Path(exists=True, dir_okay=False)
@@ -95,15 +96,48 @@ def kernel(
 )
 @click.option(
     '-m', '--method',
-    help='Difussion method',
+    help='Diffusion method',
     type=click.Choice(METHODS),
     required=True,
 )
+@click.option(
+    '-b', '--binarize',
+    help='If logFC provided in dataset, convert logFC to binary (e.g., up-regulated entities to 1, down-regulated to '
+         '-1). For scoring methods that accept quantitative values (i.e., raw & z), node labels can also be codified '
+         'with LogFC (in this case, set binarize==False).',
+    type=bool,
+    default=True,
+    show_default=True,
+)
+@click.option(
+    '-t', '--threshold',
+    help='Codify node labels by applying a threshold to logFC in input.',
+    type=float,
+)
+@click.option(
+    '-a', '--absolute_value',
+    help='Codify node labels by applying threshold to |logFC| in input. If absolute_value is set to False, node labels '
+         'will be signed.',
+    type=bool,
+    default=True,
+    show_default=True,
+)
+@click.option(
+    '-p', '--p_value',
+    help='Statistical significance (p-value).',
+    type=float,
+    default=0.05,
+    show_default=True,
+)
 def diffuse(
         network: str,
-        input: str,
+        data: str,
         output: str,
         method: str,
+        binarize: bool,
+        absolute_value: bool,
+        threshold: float,
+        p_value: float,
 ):
     """Run a diffusion method over a network or pre-generated kernel."""
     click.secho(f'{EMOJI} Loading graph from {network} {EMOJI}')
@@ -116,16 +150,22 @@ def diffuse(
         f'{EMOJI}'
     )
 
-    input_scores = _process_input(input)
+    click.secho(f'Codifying data from {data}.')
+
+    input_scores_dict = process_input(data, method, binarize, absolute_value, p_value, threshold)
+
+    click.secho(f'Running the diffusion algorithm.')
 
     results = run_diffusion(
-        input_scores,
+        input_scores_dict,
         method,
         graph,
     )
 
     json.dump(results, output, indent=2)
 
+    click.secho(f'Finished!')
+
 
 if __name__ == '__main__':
     main()
