@@ -27,27 +27,52 @@ ensure_output_dirs()
 #: DiffuPy emoji
 EMOJI = "🌐"
 
+"""Available diffusion methods"""
+
+#: raw
+RAW = 'raw'
+#: ml
+ML = 'ml'
+#: gm
+GM = 'gm'
+#: mc
+MC = 'mc'
+#: z
+Z = 'z'
+#: ber_s
+BER_S = 'ber_s'
+#: ber p
+BER_P = 'ber_p'
+
 #: DiffuPy diffusion methods
 METHODS = {
-    "raw",
-    "ml",
-    "gm",
-    "mc",
-    "z",
-    "ber_s",
-    "ber_p",
+    RAW,
+    ML,
+    GM,
+    MC,
+    Z,
+    BER_S,
+    BER_P,
 }
 
-
 """Available formats"""
 
+#: csv
 CSV = 'csv'
+#: tsv
 TSV = 'tsv'
+#: graphML
 GRAPHML = 'graphml'
+#: bel
 BEL = 'bel'
+#: node link json
 NODE_LINK_JSON = 'json'
+#: pickle
 BEL_PICKLE = 'pickle'
+#: gml
 GML = 'gml'
+#: edge list
+EDGE_LIST = '.lst'
 
 #: DiffuPath available network formats
 FORMATS = [
@@ -65,11 +90,30 @@ FORMAT_SEPARATOR_MAPPING = {
     TSV: '\t'
 }
 
+"""Optional parameters"""
+#: Expression value threshold
+THRESHOLD = 'threshold'
+#: Absolute value of expression level
+ABSOLUTE_VALUE_EXP = 'absolute_value'
+
 """Acceptable column names of user submitted network"""
 
 #: Column name for source node
-SOURCE = 'source'
+SOURCE = 'Source'
 #: Column name for target node
-TARGET = 'target'
+TARGET = 'Target'
 #: Column name for relation
-RELATION = 'relation '
+RELATION = 'Relation '
+
+"""Dataset column names"""
+
+#: Node name
+NODE = 'Node'
+#: Node type
+NODE_TYPE = 'NodeType'
+#: Log2 fold change (logFC)
+LOG_FC = 'LogFC'
+#: Statistical significance (p-value)
+P_VALUE = 'p-value'
+#: Label
+LABEL = 'Label'
