@@ -4,18 +4,21 @@
 
 import json
 import logging
+import pickle
 import warnings
-from typing import List
+from typing import List, Tuple
 
 import networkx as nx
 import numpy as np
 import pandas as pd
 import pybel
-from networkx import DiGraph, read_graphml, read_gml, node_link_graph
+
+from networkx import DiGraph, read_graphml, read_gml, node_link_graph, read_edgelist
 
 from .constants import *
 from .constants import CSV, TSV, GRAPHML, GML, BEL, BEL_PICKLE, NODE_LINK_JSON, EMOJI, FORMATS
 
+
 log = logging.getLogger(__name__)
 
 
@@ -124,7 +127,11 @@ def decode_labels(labels):
 
     for label in labels:
         if not isinstance(label, str):
-            label = label.decode('utf-8').replace('"', '')
+
+            if isinstance(label, int):
+                label = str(label)
+            else:
+                label = label.decode('utf-8').replace('"', '')
 
         labels_decode.append(label)
 
@@ -169,26 +176,29 @@ def get_simple_graph_from_multigraph(multigraph):
 """Check formats of networks """
 
 
-def _format_checker(format: str) -> None:
+def _format_checker(fmt: str) -> None:
     """Check column sep."""
-    if format not in FORMATS:
+    if fmt not in FORMATS:
         raise ValueError(
-            f'The selected sep {format} is not valid. Please ensure you use one of the following formats: '
+            f'The selected sep {fmt} is not valid. Please ensure you use one of the following formats: '
             f'{FORMATS}'
         )
 
 
-def _read_network_file(path: str, format: str) -> pd.DataFrame:
+"""Process networks"""
+
+
+def _read_network_file(path: str, fmt: str) -> pd.DataFrame:
     """Read network file."""
-    _format_checker(format)
+    _format_checker(fmt)
 
     df = pd.read_csv(
         path,
         header=0,
-        sep=FORMAT_SEPARATOR_MAPPING[CSV] if format == CSV else FORMAT_SEPARATOR_MAPPING[TSV]
+        sep=FORMAT_SEPARATOR_MAPPING[CSV] if fmt == CSV else FORMAT_SEPARATOR_MAPPING[TSV]
     )
 
-    if SOURCE and TARGET not in df.columns:
+    if SOURCE not in df.columns or TARGET not in df.columns:
         raise ValueError(
             f'Ensure that your file contains columns for {SOURCE} and {TARGET}. The column for {RELATION} is optional'
             f'and can be omitted.'
@@ -198,7 +208,7 @@ def _read_network_file(path: str, format: str) -> pd.DataFrame:
 
 
 def process_network(path: str, sep: str) -> DiGraph:
-    """Return network from dataframe."""
+    """Return network from dataFrame."""
     _format_checker(sep)
 
     df = _read_network_file(path, sep)
@@ -218,7 +228,7 @@ def process_network(path: str, sep: str) -> DiGraph:
             # Store edge in the graph
             graph.add_edge(
                 sub_name, obj_name,
-                relation=relation
+                relation=relation,
             )
 
         else:
@@ -235,38 +245,49 @@ def load_json_file(path: str) -> DiGraph:
         return json.load(f)
 
 
-def process_network_from_cli(network: str) -> nx.Graph:
+def from_pickle(input_path):
+    """Read from pickle file."""
+    with open(input_path, 'rb') as f:
+        unpickler = pickle.Unpickler(f)
+        return unpickler.load()
+
+
+def process_network_from_cli(path: str) -> nx.Graph:
     """Load network from path."""
-    if network.endswith(CSV):
-        graph = process_network(network, CSV)
+    if path.endswith(CSV):
+        graph = process_network(path, CSV)
 
-    elif network.endswith(TSV):
-        graph = process_network(network, TSV)
+    elif path.endswith(TSV):
+        graph = process_network(path, TSV)
 
-    elif network.endswith(GRAPHML):
-        graph = read_graphml(network)
+    elif path.endswith(GRAPHML):
+        graph = read_graphml(path)
 
-    elif network.endswith(GML):
-        graph = read_gml(network)
+    elif path.endswith(GML):
+        graph = read_gml(path)
 
-    elif network.endswith(BEL):
-        graph = pybel.from_path(network)
+    elif path.endswith(BEL):
+        graph = pybel.from_path(path)
 
-    elif network.endswith(BEL_PICKLE):
-        graph = pybel.from_pickle(network)
+    elif path.endswith(BEL_PICKLE):
+        graph = pybel.from_pickle(path)
 
-    elif network.endswith(NODE_LINK_JSON):
-        data = load_json_file(network)
+    elif path.endswith(EDGE_LIST):
+        graph = read_edgelist(path)
+
+    elif path.endswith(NODE_LINK_JSON):
+        data = load_json_file(path)
         graph = node_link_graph(data)
 
     else:
         raise IOError(
-            f'{EMOJI} The selected format {format} is not valid. Please ensure you use one of the following formats: '
+            f'{EMOJI} The selected format is not valid. Please ensure you use one of the following formats: '
             f'{FORMATS}'
         )
     return graph
 
 
-def _process_input(input):
-    """Read input file and prepare scores."""
-    raise NotImplementedError('Not yet implemented')
+def process_kernel_from_cli(path: str):
+    """Process kernel from cli."""
+    # TODO process different kinds of input format kernel
+    return from_pickle(path)
